<?php
class PluginMaintenanceModeExtended extends Plugin
{
    private $loadOnController = [
        'configure-plugin',
    ];
    public function init(): void
    {
        $this->dbFields = [
            'enable' => false,
            'bgColor' => '#1c2022',
            'textColor' => '#eeeeee',
            'showImage' => true,
            'image' => '',
            'message' => 'Temporarily down for maintenance.'
        ];
    }
    public function adminBodyEnd(): ?string
    {
        global $url;
        if (in_array($GLOBALS['ADMIN_CONTROLLER'], $this->loadOnController)) {
            $slug = basename($url->uri());
            if ($slug !== get_class($this)) {
                return null;
            }

            return '<script src="' . $this->htmlPath() . 'js/jscolor.min.js"></script>';
        }
        return null;
    }
    public function form(): string
    {
        global $L;
        $html = '<div style="width: 80%; float:left;">';
        $options = [
            'enable' => [
                'label' => $L->get('Maintenance Mode'),
                'inputType' => 'select',
                'options' => [
                    'true' => $L->get('Enabled'),
                    'false' => $L->get('Disabled'),
                ],
            ],
            'bgColor' => [
                'label' => $L->get('Background Color'),
                'inputType' => 'text',
                'class' => 'jscolor',
            ],
            'textColor' => [
                'label' => $L->get('Text Color'),
                'inputType' => 'text',
                'class' => 'jscolor',
            ],
            'showImage' => [
                'label' => $L->get('Display Image'),
                'inputType' => 'select',
                'options' => [
                    'true' => $L->get('Yes'),
                    'false' => $L->get('No'),
                ],
            ],
            'image' => [
                'label' => $L->get('Custom Image URL'),
                'inputType' => 'text',
            ],
            'message' => [
                'label' => $L->get('Custom Maintenance Message'),
                'inputType' => 'text',
            ],
        ];
        foreach ($options as $name => $option) {
            $value = $this->getValue($name);
            $valueString = is_bool($value) ? ($value ? 'true' : 'false') : $value;
            $html .= "<div><label>{$option['label']}</label>";
            if ($option['inputType'] === 'select') {
                $html .= "<select name='{$name}'>";
                foreach ($option['options'] as $optValue => $optLabel) {
                    $isSelected = ($valueString === $optValue) ? 'selected' : '';
                    $html .= "<option value='{$optValue}' {$isSelected}>{$optLabel}</option>";
                }
                $html .= '</select>';
            } else {
                $class = $option['class'] ?? '';
                $html .= "<input name='{$name}' id='{$name}' class='{$class}' type='text' value='{$value}'>";
            }
            $html .= '</div>';
        }
        $html .= '</div>';
        return $html;
    }
    public function beforeSiteLoad(): void
    {
        $title = str_replace('<title>', '<title>[Maintenance Mode] ', Theme::metaTags('title'));
        $description = Theme::metaTags('description');
        $favicon = Theme::favicon('img/favicon.png');
        if ($this->getValue('enable')) {
            $login = new Login();
            if ($login->role() !== 'admin' && $login->role() !== 'editor') {
                $displayImg = '<img src="' . $this->htmlPath() . 'img/maintenance-mode.png" style="max-width: 90%">';
                if ($this->getValue('image')) { $displayImg = '<img src="' . $this->getValue('image') . '" style="max-width: 90%">'; }
                if ($this->getValue('showImage') === false) { $displayImg = ''; }
                $offline = <<<HTML
<html>
<head>
    {$title}
    {$description}
    {$favicon}
    <style>
        html {margin:0; padding:0; background: #{$this->getValue('bgColor')};}
        body {margin:0; padding:0;}
    </style>
</head>
<body>
    <div style="height: 100%; margin: 0; padding: 0; color: #{$this->getValue('textColor')}; font-family: sans-serif; display: flex; flex-direction: column; align-items: center; justify-content: center;">
        {$displayImg}
        <h1>{$this->getValue('message')}</h1>
    </div>
</body>
</html>
HTML;
                echo $offline;
                exit();
            }
        }
    }
}